MultiDrizzle Reference Table — drizzlepac 1.0.6 (14-Aug-2012) documentation

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »
- Utilities »

# MultiDrizzle Reference Table

This module supports the interpretation of the MDRIZTAB for processing as used in the pipeline.

`drizzlepac.mdzhandler.` `cleanBlank`(value)

`drizzlepac.mdzhandler.` `cleanInt`(value)

`drizzlepac.mdzhandler.` `cleanNaN`(value)

`drizzlepac.mdzhandler.` `findFormat`(format)

`drizzlepac.mdzhandler.` `getMdriztabParameters`(files)

  Gets entry in MDRIZTAB where task parameters live. This method returns a record array mapping the selected row.

`drizzlepac.mdzhandler.` `toBoolean`(flag)

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »
- Utilities »